ngff_zarr.cli_input_to_ngff_image - ngff-zarr
Description: Module Contents: Functions:,, cli_input_to_ngff_image,,,,, API:

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Edit this page
Toggle table of contents sidebar

# `ngff_zarr.cli_input_to_ngff_image`

## Module Contents

### Functions

`cli_input_to_ngff_image` |

### API

ngff_zarr.cli_input_to_ngff_image.cli_input_to_ngff_image(backend: ngff_zarr.detect_cli_io_backend.ConversionBackend, input, output_scale: int = 0) → ngff_zarr.ngff_image.NgffImage